/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLLinkElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLLinkElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLLinkElement.h"
#include "gdom/PrivateIntGdomHTMLLinkElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLLinkElement::GDOMHTMLLinkElement(PassRefPtr<WebCore::HTMLLinkElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLLinkElement.h"
#include <gdom/GdomHTMLLinkElement.h>
#include <gdom/PrivateGdomHTMLLinkElement.h>
#include <gdom/PrivateIntGdomHTMLLinkElement.h>
#include <gdom/GdomHTMLLinkElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLLinkElement, gdom_html_link_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLLinkElementPrivate {
    class WebCore::HTMLLinkElement *item;
};

#define GDOM_HTML_LINK_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_LINK_ELEMENT, GdomHTMLLinkElementPrivate))
*/
G_END_DECLS
WebCore::HTMLLinkElement *
gdom_html_link_element_get_private(GdomHTMLLinkElement *request)
{
    GDOMHTMLLinkElement *res;
    res = static_cast<GDOMHTMLLinkElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLLinkElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_DISABLED,
    PROP_CHARSET,
    PROP_HREF,
    PROP_HREFLANG,
    PROP_MEDIA,
    PROP_REL,
    PROP_REV,
    PROP_TARGET,
    PROP_TYPE,
    PROP_SHEET,
};


static void gdom_html_link_element_finalize(GObject* object)
{
    /*GdomHTMLLinkElement* request = GDOM_HTML_LINK_ELEMENT(object);*/
    /*GdomHTMLLinkElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_link_element_parent_class)->finalize(object);
}

static void gdom_html_link_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLLinkElement *self = GDOM_HTML_LINK_ELEMENT(object);
    WebCore::HTMLLinkElement * gself = (gdom_html_link_element_get_private(self));
    switch (prop_id) {
     case PROP_DISABLED:
    {
         gself->setDisabled((g_value_get_boolean (value)) );
         break;
    }
     case PROP_CHARSET:
    {
         gself->setCharset(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HREF:
    {
         gself->setHref(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HREFLANG:
    {
         gself->setHreflang(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_MEDIA:
    {
         gself->setMedia(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_REL:
    {
         gself->setRel(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_REV:
    {
         gself->setRev(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_TARGET:
    {
         gself->setTarget(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_TYPE:
    {
         gself->setType(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_link_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLLinkElement *self = GDOM_HTML_LINK_ELEMENT(object);
    WebCore::HTMLLinkElement * gself = (gdom_html_link_element_get_private(self));
    switch (prop_id) {
    case PROP_DISABLED:
    {
         g_value_set_boolean (value, gself->disabled());
         break;
    }
    case PROP_CHARSET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->charset()));
         break;
    }
    case PROP_HREF:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->href()));
         break;
    }
    case PROP_HREFLANG:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->hreflang()));
         break;
    }
    case PROP_MEDIA:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->media()));
         break;
    }
    case PROP_REL:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->rel()));
         break;
    }
    case PROP_REV:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->rev()));
         break;
    }
    case PROP_TARGET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->target()));
         break;
    }
    case PROP_TYPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->type()));
         break;
    }
    case PROP_SHEET:
    {
         PassRefPtr<WebCore::StyleSheet> ptr = gself->sheet();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_link_element_class_init(GdomHTMLLinkElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_link_element_finalize;
    g_klass->set_property = gdom_html_link_element__set_property_fn;
    g_klass->get_property = gdom_html_link_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_DISABLED,
            g_param_spec_boolean ("disabled", /* name */
                "html_link_element_disabled", /* short description */
                "read-write  gboolean HTMLLinkElement.disabled", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CHARSET,
            g_param_spec_string ("charset", /* name */
                "html_link_element_charset", /* short description */
                "read-write  gchar * HTMLLinkElement.charset", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HREF,
            g_param_spec_string ("href", /* name */
                "html_link_element_href", /* short description */
                "read-write  gchar * HTMLLinkElement.href", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HREFLANG,
            g_param_spec_string ("hreflang", /* name */
                "html_link_element_hreflang", /* short description */
                "read-write  gchar * HTMLLinkElement.hreflang", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_MEDIA,
            g_param_spec_string ("media", /* name */
                "html_link_element_media", /* short description */
                "read-write  gchar * HTMLLinkElement.media", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_REL,
            g_param_spec_string ("rel", /* name */
                "html_link_element_rel", /* short description */
                "read-write  gchar * HTMLLinkElement.rel", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_REV,
            g_param_spec_string ("rev", /* name */
                "html_link_element_rev", /* short description */
                "read-write  gchar * HTMLLinkElement.rev", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TARGET,
            g_param_spec_string ("target", /* name */
                "html_link_element_target", /* short description */
                "read-write  gchar * HTMLLinkElement.target", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TYPE,
            g_param_spec_string ("type", /* name */
                "html_link_element_type", /* short description */
                "read-write  gchar * HTMLLinkElement.type", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SHEET,
            g_param_spec_object ("sheet", /* name */
                "html_link_element_sheet", /* short description */
                "read-only  GdomStyleSheet * HTMLLinkElement.sheet", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_STYLE_SHEET, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLLinkElementPrivate));*/
}

static void gdom_html_link_element_init(GdomHTMLLinkElement* request)
{
    /*GdomHTMLLinkElementPrivate* priv = GDOM_HTML_LINK_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

